import { Box } from "@mui/material";
import { ControlsContainer } from "./VideoPlayer-styles";
// import { MobileControlsBar } from "./MobileControlsBar";
import {
  FullscreenButton,
  ObjectFitButton,
  PictureInPictureButton,
  PlaybackRate,
  PlayButton,
  ProgressSlider,
  ReloadButton,
  VideoTime,
  VolumeControl,
} from "./VideoControls";
import { Ref } from "react";

interface VideoControlsBarProps {
  canPlay: boolean
  isScreenSmall: boolean
  controlsHeight?: string
  videoRef:Ref<HTMLVideoElement>;
  progress: number;
  duration: number
  isPlaying: boolean;
  togglePlay: ()=> void;
  reloadVideo: ()=> void;
  volume: number
  onVolumeChange: (_: any, val: number)=> void
  toggleFullscreen: ()=> void
  extractFrames: (time: number)=> void
  showControls: boolean;
  showControlsFullScreen: boolean;
  isFullScreen: boolean;
  playerRef: any
}

export const VideoControlsBar = ({showControls, isFullScreen, showControlsFullScreen, reloadVideo, onVolumeChange, volume, isPlaying, canPlay, isScreenSmall, controlsHeight, videoRef, playerRef, duration, progress, togglePlay, toggleFullscreen, extractFrames}: VideoControlsBarProps) => {

  const showMobileControls = isScreenSmall && canPlay;

  const controlGroupSX = {
    display: "flex",
    gap: "5px",
    alignItems: "center",
    height: controlsHeight,
  };

  let additionalStyles: React.CSSProperties = {}
  if(isFullScreen && showControlsFullScreen){
    additionalStyles = {
      opacity: 1,
      position: 'fixed',
      bottom: 0
    }
  }

  return (
    <ControlsContainer
      style={{
        padding: "0px",
        opacity: showControls ? 1 : 0,
        pointerEvents: showControls ? 'auto' : 'none',
        transition: 'opacity 0.4s ease-in-out',
        // ...additionalStyles
        // height: controlsHeight,
      }}
    >
      {showMobileControls ? (
        null
        // <MobileControlsBar />
      ) : canPlay ? (
        <Box sx={{
          display: 'flex',
          flexDirection: 'column',
          width: '100%'
        }}>
         
        <ProgressSlider extractFrames={extractFrames} playerRef={playerRef} progress={progress} duration={duration} />
        <Box sx={{
          width: '100%',
          display: 'flex'
        }}>
          <Box sx={controlGroupSX}>
            <PlayButton isPlaying={isPlaying} togglePlay={togglePlay}/>
            <ReloadButton reloadVideo={reloadVideo} />

            

            <VolumeControl onVolumeChange={onVolumeChange} volume={volume} sliderWidth={"100px"} />
            <VideoTime videoRef={videoRef} progress={progress}/>
          </Box>

          <Box sx={controlGroupSX}>
            <PlaybackRate />
            <ObjectFitButton />
            <PictureInPictureButton />
            <FullscreenButton toggleFullscreen={toggleFullscreen} />
          </Box>
          </Box>
        </Box>
      ) : null}
    </ControlsContainer>
  );
};
